@@ -7,7 +7,7 @@ app = Flask(__name__)
 @app.route('/')
 def index():
     buf = io.BytesIO()
-    buf.write('hello world')
+    buf.write(b'hello world')
     buf.seek(0)
     return send_file(buf,
                      attachment_filename="testing.txt",
