@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -
 #
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
@@ -25,7 +24,7 @@ from test import app as app1
 from test import app as app2
 
 
-class Application(object):
+class Application:
     def __init__(self):
         self.map = Mapper()
         self.map.connect('app1', '/app1url', app=app1)
