@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -
 #
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
 
 import os
-import unittest.mock as mock
+from unittest import mock
 
 import gunicorn.app.base
 import gunicorn.arbiter
