@@ -1,5 +1,3 @@
-# -*- encoding: utf-8 -*-
-
 import io
 import t
 import pytest
@@ -9,7 +7,7 @@ from gunicorn import util
 from gunicorn.http.body import Body, LengthReader, EOFReader
 from gunicorn.http.wsgi import Response
 from gunicorn.http.unreader import Unreader, IterUnreader, SocketUnreader
-from gunicorn.http.errors import InvalidHeader, InvalidHeaderName
+from gunicorn.http.errors import InvalidHeader, InvalidHeaderName, InvalidHTTPVersion
 from gunicorn.http.message import TOKEN_RE
 
 
@@ -238,3 +236,8 @@ def test_eof_reader_read_invalid_size():
         reader.read([100])
     with pytest.raises(ValueError):
         reader.read(-100)
+
+
+def test_invalid_http_version_error():
+    assert str(InvalidHTTPVersion('foo')) == "Invalid HTTP Version: 'foo'"
+    assert str(InvalidHTTPVersion((2, 1))) == 'Invalid HTTP Version: (2, 1)'
