@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -
 #
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
 
-import unittest.mock as mock
+from unittest import mock
 
 from gunicorn import sock
 
