@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -
 #
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
 
 from contextlib import contextmanager
 import os
-import unittest.mock as mock
+from unittest import mock
 
 import pytest
 
